@@ -62,6 +62,20 @@ def detect_center(array):
 def detect_border(array, space, threshold_w, threshold_h):
     height, width, _ = array.shape
     top, right, bottom, left = (0, 0, 0, 0)
+    # detect the top border
+    for start_h in range(0, height, space):
+        end_h = min(start_h + threshold_h, height)
+        nnz = np.count_nonzero(array[start_h:end_h, :, :])
+        if nnz != 0:
+            top = min(start_h, height)
+            break
+    # detect the bottom border
+    for end_h in range(height, top, -space):
+        start_h = max(end_h - threshold_h, 0)
+        nnz = np.count_nonzero(array[start_h:end_h, :, :])
+        if nnz != 0:
+            bottom = min(end_h, height)
+            break
     # detect the left border
     for start_w in range(0, width, space):
         end_w = min(start_w + threshold_w, width)
@@ -76,28 +90,14 @@ def detect_border(array, space, threshold_w, threshold_h):
         if nnz != 0:
             right = min(end_w, width)
             break
-    # detect the top border
-    for start_h in range(0, height, space):
-        end_h = min(start_h + threshold_h, height)
-        nnz = np.count_nonzero(array[:, start_h:end_h, :])
-        if nnz != 0:
-            top = min(end_h, height)
-            break
-    # detect the bottom border
-    for end_h in range(height, top, -space):
-        start_h = max(end_h - threshold_h, 0)
-        nnz = np.count_nonzero(array[:, start_h:end_h, :])
-        if nnz != 0:
-            bottom = min(start_h, height)
-            break
     return top, bottom, left, right
 
 
 def detect_frame(array, space, threshold, crop_from='center'):
     reversed_array = array - 255
     height, width, _ = array.shape
-    threshold_h = max(int(height * threshold), 1)
-    threshold_w = max(int(width * threshold), 1)
+    threshold_h = min(max(int(height * threshold), 1), space)
+    threshold_w = min(max(int(width * threshold), 1), space)
 
     if crop_from == 'center':
         cx, cy = detect_center(reversed_array)
